Function dockertest_server::common::rand_string [−][src]
pub fn rand_string(length: usize) -> StringExpand description
Generates a random string of characters of the given length.
pub fn rand_string(length: usize) -> StringGenerates a random string of characters of the given length.