Struct dockertest_server::server::ContainerConfig [−][src]
pub struct ContainerConfig {
pub args: Vec<String>,
pub env: HashMap<String, String>,
pub handle: String,
pub name: String,
pub source: Source,
pub version: String,
pub ports: Option<Vec<(u32, u32)>>,
pub wait: Option<Box<dyn WaitFor>>,
}Expand description
A helper struct for creating Compositions from a set of common configuration parameters.
This type can be freely cast into a Composition. It is only intended for basic use-cases where limited control over how the Composition is configured is acceptable.
Fields
args: Vec<String>env: HashMap<String, String>handle: Stringname: Stringsource: Sourceversion: Stringports: Option<Vec<(u32, u32)>>wait: Option<Box<dyn WaitFor>>Trait Implementations
Performs the conversion.