Trait dockertest_server::server::Config[][src]

pub trait Config: Clone + Send + Sync {
    fn into_composition(self) -> Composition;
fn handle(&self) -> &str; }
A configuration capable of configuring a Server.

Types that implement this trait are intended to have a one-to-one relationship with a Server as specified by Server::Config. The implementation is left intentionally sparse in order to maximize the process of creating a container Composition. The [generate_composition] helper function is provided for creating a Composition from the usual required configuration options.

See also Test.

Required methods

Implementors